@@ -122,9 +122,9 @@ class CoreGrilo(GObject.GObject):
                 and source.props.source_id not in self._wrappers.keys()
                 and new_state == TrackerState.AVAILABLE):
             new_wrapper = GrlTrackerWrapper(
-                source, self._coremodel, self._coreselection, self)
+                source, self._coremodel, self._coreselection, self,
+                self._tracker_wrapper)
             self._wrappers[source.props.source_id] = new_wrapper
-            self.props.tracker_available = True
         # elif source.props.source_id[:10] == "grl-dleyna":
         #     new_wrapper = GrlDLeynaWrapper(
         #         source, self._coremodel, self._coreselection, self)
