@@ -97,34 +97,6 @@ class PlayerPlaylist(GObject.GObject):
 
         self.connect("notify::repeat-mode", self._on_repeat_mode_changed)
 
-    @log
-    def change_position(self, prev_pos, new_pos):
-        """Change order of a song in the playlist
-
-        :param int prev_pos: previous position
-        :param int new_pos: new position
-        :return: new index of the song being played. -1 if unchanged
-        :rtype: int
-        """
-        pass
-
-    @log
-    def add_song(self, song, song_index):
-        """Add a song to the playlist.
-
-        :param Grl.Media song: new song
-        :param int song_index: song position
-        """
-        pass
-
-    @log
-    def remove_song(self, song_index):
-        """Remove a song from the playlist.
-
-        :param int song_index: index of the song to remove
-        """
-        pass
-
     @log
     def has_next(self):
         """Test if there is a song after the current one.
@@ -154,6 +126,25 @@ class PlayerPlaylist(GObject.GObject):
 
         return False
 
+    def get_next(self):
+        """Get the next song in the playlist.
+
+        :return: The next CoreSong or None.
+        :rtype: CoreSong
+        """
+        if not self.has_next():
+            return None
+
+        if self.props.repeat_mode == RepeatMode.SONG:
+            next_position = self.props.position
+        elif (self.props.repeat_mode == RepeatMode.ALL
+                and self.props.position == self._model.get_n_items() - 1):
+            next_position = 0
+        else:
+            next_position = self.props.position + 1
+
+        return self._model[next_position]
+
     @log
     def next(self):
         """Go to the next song in the playlist.
@@ -378,6 +369,8 @@ class Player(GObject.GObject):
     """
 
     __gsignals__ = {
+        # FIXME: This signal is no longer used, but is connected to
+        # by MPRIS.
         'playlist-changed': (GObject.SignalFlags.RUN_FIRST, None, ()),
         'seek-finished': (GObject.SignalFlags.RUN_FIRST, None, ()),
         'song-changed': (GObject.SignalFlags.RUN_FIRST, None, ())
@@ -466,19 +459,20 @@ class Player(GObject.GObject):
     @log
     def _on_about_to_finish(self, klass):
         if self.props.has_next:
-            self._playlist.next()
-
-            new_url = self._playlist.props.current_song.props.url
+            next_coresong = self._playlist.get_next()
+            new_url = next_coresong.props.url
             self._gst_player.props.url = new_url
             self._gapless_set = True
 
     @log
     def _on_eos(self, klass):
+        self._playlist.next()
+
         if self._gapless_set:
             # After 'eos' in the gapless case, the pipeline needs to be
             # hard reset.
             self.stop()
-            self.play()
+            self.play(self.props.current_song)
         else:
             self.stop()
 
@@ -495,6 +489,9 @@ class Player(GObject.GObject):
             self.next()
 
     def _on_stream_start(self, klass):
+        if self._gapless_set:
+            self._playlist.next()
+
         self._gapless_set = False
         self._time_stamp = int(time.time())
 
@@ -569,45 +566,6 @@ class Player(GObject.GObject):
         else:
             self.play()
 
-    @log
-    def playlist_change_position(self, prev_pos, new_pos):
-        """Change order of a song in the playlist.
-
-        :param int prev_pos: previous position
-        :param int new_pos: new position
-        :return: new index of the song being played. -1 if unchanged
-        :rtype: int
-        """
-        current_index = self._playlist.change_position(prev_pos, new_pos)
-        if current_index >= 0:
-            self.emit('playlist-changed')
-        return current_index
-
-    @log
-    def remove_song(self, song_index):
-        """Remove a song from the current playlist.
-
-        :param int song_index: position of the song to remove
-        """
-        if self.props.position == song_index:
-            if self.props.has_next:
-                self.next()
-            elif self.props.has_previous:
-                self.previous()
-            else:
-                self.stop()
-        self._playlist.remove_song(song_index)
-        self.emit('playlist-changed')
-
-    @log
-    def add_song(self, song, song_index):
-        """Add a song to the current playlist.
-
-        :param int song_index: position of the song to add
-        """
-        self._playlist.add_song(song, song_index)
-        self.emit('playlist-changed')
-
     @log
     def playing_playlist(self, playlist_type, playlist_id):
         """Test if the current playlist matches type and id.
