@@ -25,15 +25,11 @@
 from gi.repository import GObject, Gtk
 
 from gnomemusic import log
-from gnomemusic.widgets.starhandlerwidget import StarHandlerWidget
 
 
 class BaseView(Gtk.Stack):
     """Base Class for all view classes"""
 
-    _now_playing_icon_name = 'media-playback-start-symbolic'
-    _error_icon_name = 'dialog-error-symbolic'
-
     selected_items_count = GObject.Property(type=int, default=0, minimum=0)
     selection_mode = GObject.Property(type=bool, default=False)
 
@@ -41,18 +37,16 @@ class BaseView(Gtk.Stack):
         return '<BaseView>'
 
     @log
-    def __init__(self, name, title, window, sidebar=None):
+    def __init__(self, name, title, application, sidebar=None):
         """Initialize
         :param name: The view name
         :param title: The view title
-        :param GtkWidget window: The main window
+        :param GtkApplication application: The application object
         :param sidebar: The sidebar object (Default: Gtk.Box)
         """
-
         super().__init__(transition_type=Gtk.StackTransitionType.CROSSFADE)
 
         self._grid = Gtk.Grid(orientation=Gtk.Orientation.HORIZONTAL)
-        self._offset = 0
         self._box = Gtk.Box(orientation=Gtk.Orientation.VERTICAL)
 
         # Setup the main view
@@ -63,18 +57,15 @@ class BaseView(Gtk.Stack):
 
         self._grid.add(self._box)
 
-        self._star_handler = StarHandlerWidget(self, 6)
-        self._window = window
-        self._headerbar = window._headerbar
+        self._window = application.props.window
+        self._headerbar = self._window._headerbar
 
         self.name = name
         self.title = title
 
         self.add(self._grid)
         self.show_all()
-        # self._view.hide()
 
-        self._init = False
         self._selection_mode_id = self.connect(
             "notify::selection-mode", self._on_selection_mode_changed)
 
@@ -82,46 +73,12 @@ class BaseView(Gtk.Stack):
             'selection-mode', self._window, 'selection-mode',
             GObject.BindingFlags.BIDIRECTIONAL)
 
-        if not self._init:
-            self._on_grilo_ready()
-
-    @log
-    def _on_changes_pending(self, data=None):
-        pass
-
     @log
     def _setup_view(self):
         """Instantiate and set up the view object"""
         pass
 
-    @log
-    def _on_grilo_ready(self, data=None):
-        if (self._headerbar.props.stack.props.visible_child == self
-                and not self._init):
-            self._populate()
-
-        self._headerbar.props.stack.connect(
-            'notify::visible-child', self._on_headerbar_visible)
-
-    @log
-    def _on_headerbar_visible(self, widget, param):
-        if (self == widget.get_visible_child()
-                and not self._init):
-            self._populate()
-
-    @log
-    def _populate(self, data=None):
-        pass
-
     @log
     def _on_selection_mode_changed(self, widget, data=None):
         if not self.props.selection_mode:
             self.unselect_all()
-
-    @log
-    def _on_item_activated(self, widget, id, path):
-        pass
-
-    @log
-    def get_selected_songs(self, callback):
-        callback([])
