@@ -46,22 +46,19 @@ class ArtistAlbumsWidget(Gtk.ListBox):
     selected_items_count = GObject.Property(type=int, default=0, minimum=0)
     selection_mode = GObject.Property(type=bool, default=False)
 
-    __gsignals__ = {
-        "ready": (GObject.SignalFlags.RUN_FIRST, None, ()),
-    }
-
     def __repr__(self):
         return '<ArtistAlbumsWidget>'
 
     @log
     def __init__(
-            self, coreartist, player, window, selection_mode_allowed=False):
+            self, coreartist, application, selection_mode_allowed=False):
         super().__init__()
+
+        self._application = application
         self._artist = coreartist.props.artist
         self._model = coreartist.props.model
-        self._player = player
+        self._player = self._application.props.player
         self._selection_mode_allowed = selection_mode_allowed
-        self._window = window
 
         self._widgets = []
 
@@ -70,7 +67,6 @@ class ArtistAlbumsWidget(Gtk.ListBox):
         self._songs_grid_size_group = Gtk.SizeGroup.new(
             Gtk.SizeGroupMode.HORIZONTAL)
 
-        self._nb_albums_loaded = 0
         self._model.props.model.connect_after(
             "items-changed", self. _on_model_items_changed)
         self.bind_model(self._model, self._add_album)
@@ -84,19 +80,19 @@ class ArtistAlbumsWidget(Gtk.ListBox):
         if self.props.selection_mode:
             return
 
-        coremodel = self._player._app.props.coremodel
+        coremodel = self._application.props.coremodel
 
-        def _on_playlist_loaded(artistalbumwidget):
+        def _on_playlist_loaded(klass):
             self._player.play(song_widget.props.coresong)
             coremodel.disconnect(signal_id)
 
         signal_id = coremodel.connect("playlist-loaded", _on_playlist_loaded)
-        coremodel.set_playlist_model(PlayerPlaylist.Type.ARTIST, self._model)
+        coremodel.set_player_model(PlayerPlaylist.Type.ARTIST, self._model)
 
     def _add_album(self, corealbum):
         widget = ArtistAlbumWidget(
             corealbum, self._selection_mode_allowed,
-            self._songs_grid_size_group, self._cover_size_group, self._window)
+            self._songs_grid_size_group, self._cover_size_group)
 
         self.bind_property(
             'selection-mode', widget, 'selection-mode',
@@ -104,18 +100,10 @@ class ArtistAlbumsWidget(Gtk.ListBox):
             | GObject.BindingFlags.SYNC_CREATE)
 
         self._widgets.append(widget)
-        widget.connect("ready", self._on_album_ready)
         widget.connect("song-activated", self._song_activated)
 
         return widget
 
-    def _on_album_ready(self, artistalbumwidget):
-        self._nb_albums_loaded += 1
-        if self._nb_albums_loaded == self._model.get_n_items():
-            artistalbumwidget.disconnect_by_func(self._on_album_ready)
-            self._nb_albums_loaded = 0
-            self.emit("ready")
-
     def _on_model_items_changed(self, model, position, removed, added):
         for i in range(model.get_n_items()):
             row = self.get_row_at_index(i)
@@ -137,15 +125,3 @@ class ArtistAlbumsWidget(Gtk.ListBox):
     def artist(self):
         """Artist name"""
         return self._artist
-
-    @log
-    def get_selected_songs(self):
-        """Return a list of selected songs.
-
-        :returns: selected songs
-        :rtype: list
-        """
-        songs = []
-        for widget in self._widgets:
-            songs += widget.get_selected_songs()
-        return songs
