@@ -98,7 +98,7 @@ class HeaderBar(Gtk.HeaderBar):
     _back_button = Gtk.Template.Child()
     _menu_button = Gtk.Template.Child()
 
-    search_mode_enabled = GObject.Property(type=bool, default=False)
+    search_mode_active = GObject.Property(type=bool, default=False)
     selected_items_count = GObject.Property(type=int, default=0, minimum=0)
     selection_mode_allowed = GObject.Property(type=bool, default=True)
     stack = GObject.Property(type=Gtk.Stack)
@@ -122,8 +122,8 @@ class HeaderBar(Gtk.HeaderBar):
 
         self.bind_property(
             "selection-mode", self, "show-close-button",
-            GObject.BindingFlags.INVERT_BOOLEAN |
-            GObject.BindingFlags.SYNC_CREATE)
+            GObject.BindingFlags.INVERT_BOOLEAN
+            | GObject.BindingFlags.SYNC_CREATE)
         self.bind_property(
             "selection-mode", self._cancel_button, "visible")
         self.bind_property(
@@ -134,15 +134,15 @@ class HeaderBar(Gtk.HeaderBar):
             GObject.BindingFlags.BIDIRECTIONAL)
         self.bind_property(
             "stack", self._stack_switcher, "stack",
-            GObject.BindingFlags.BIDIRECTIONAL |
-            GObject.BindingFlags.SYNC_CREATE)
+            GObject.BindingFlags.BIDIRECTIONAL
+            | GObject.BindingFlags.SYNC_CREATE)
         self.bind_property(
             "selected-items-count", self._selection_menu,
             "selected-items-count")
         self.bind_property(
-            "search-mode-enabled", self._search_button, "active",
-            GObject.BindingFlags.BIDIRECTIONAL |
-            GObject.BindingFlags.SYNC_CREATE)
+            "search-mode-active", self._search_button, "active",
+            GObject.BindingFlags.BIDIRECTIONAL
+            | GObject.BindingFlags.SYNC_CREATE)
 
         self.connect(
             "notify::selection-mode-allowed",
