@@ -1,4 +1,4 @@
-# Copyright (c) 2016 The GNOME Music Developers
+# Copyright 2019 The GNOME Music Developers
 #
 # GNOME Music is free software; you can redistribute it and/or modify
 # it under the terms of the GNU General Public License as published by
@@ -22,12 +22,11 @@
 # code, but you are not obligated to do so.  If you do not wish to do so,
 # delete this exception statement from your version.
 
-from gi.repository import Gtk, Pango
+from gi.repository import GObject, Gtk
 
 from gnomemusic import log
-from gnomemusic.grilo import grilo
-from gnomemusic.playlists import Playlists
-import gnomemusic.utils as utils
+from gnomemusic.grilowrappers.grltrackerplaylists import Playlist
+from gnomemusic.widgets.playlistdialogrow import PlaylistDialogRow
 
 
 @Gtk.Template(resource_path="/org/gnome/Music/ui/PlaylistDialog.ui")
@@ -36,13 +35,13 @@ class PlaylistDialog(Gtk.Dialog):
 
     __gtype_name__ = 'PlaylistDialog'
 
+    selected_playlist = GObject.Property(type=Playlist, default=None)
+
     _add_playlist_stack = Gtk.Template.Child()
     _normal_box = Gtk.Template.Child()
     _empty_box = Gtk.Template.Child()
     _title_bar = Gtk.Template.Child()
-    _view = Gtk.Template.Child()
-    _selection = Gtk.Template.Child()
-    _model = Gtk.Template.Child()
+    _listbox = Gtk.Template.Child()
     _cancel_button = Gtk.Template.Child()
     _select_button = Gtk.Template.Child()
     _new_playlist_button = Gtk.Template.Child()
@@ -54,7 +53,7 @@ class PlaylistDialog(Gtk.Dialog):
         return '<PlaylistDialog>'
 
     @log
-    def __init__(self, parent, playlists_todelete):
+    def __init__(self, parent):
         super().__init__()
 
         self._add_playlist_button = None
@@ -62,32 +61,14 @@ class PlaylistDialog(Gtk.Dialog):
 
         self.props.transient_for = parent
         self.set_titlebar(self._title_bar)
-        self._add_list_renderers()
-        self._populate()
-
-        self._playlists_todelete_ids = playlists_todelete.keys()
 
+        # FIXME: should we use a special model without the smart playlists?
         self._user_playlists_available = False
-        self._playlist = Playlists.get_default()
-        self._playlist.connect('playlist-created', self._on_playlist_created)
+        self._coremodel = parent._app.props.coremodel
+        self._listbox.bind_model(
+            self._coremodel.props.playlists_sort, self._create_playlist_row)
 
-    @log
-    def get_selected(self):
-        """Get the selected playlist"""
-        _iter = self._selection.get_selected()[1]
-
-        if not _iter:
-            return None
-
-        return self._model[_iter][1]
-
-    @log
-    def _add_list_renderers(self):
-        type_renderer = Gtk.CellRendererText(
-            xpad=8, ypad=8, ellipsize=Pango.EllipsizeMode.END, xalign=0.0)
-
-        col = Gtk.TreeViewColumn("Name", type_renderer, text=0)
-        self._view.append_column(col)
+        self._set_view()
 
     @log
     def _set_view(self):
@@ -103,29 +84,17 @@ class PlaylistDialog(Gtk.Dialog):
             self._add_playlist_entry = self._first_playlist_entry
 
     @log
-    def _populate(self):
-        grilo.populate_user_playlists(0, self._add_item)
-
-    @log
-    def _add_item(self, source, param, item, remaining=0, data=None):
-        if item:
-            self._add_item_to_model(item)
-        if remaining == 0:
-            self._set_view()
-
-    @log
-    def _add_item_to_model(self, item):
+    def _create_playlist_row(self, playlist):
         """Adds (non-smart only) playlists to the model"""
-
-        # Hide playlists that are going to be deleted
-        if item.get_id() in self._playlists_todelete_ids:
+        if playlist.props.is_smart:
             return None
 
         self._user_playlists_available = True
-        new_iter = self._model.insert_with_valuesv(
-            -1, [0, 1], [utils.get_media_title(item), item])
+        self._set_view()
 
-        return new_iter
+        row = PlaylistDialogRow(playlist)
+
+        return row
 
     @Gtk.Template.Callback()
     @log
@@ -139,32 +108,30 @@ class PlaylistDialog(Gtk.Dialog):
 
     @Gtk.Template.Callback()
     @log
-    def _on_item_activated(self, view, path, column):
+    def _on_selected_rows_changed(self, klass):
         self._add_playlist_entry.props.text = ""
         self._add_playlist_button.props.sensitive = False
+        selected_row = self._listbox.get_selected_row()
+        if selected_row is not None:
+            self.props.selected_playlist = selected_row.props.playlist
+        self._select_button.props.sensitive = selected_row is not None
 
-    @Gtk.Template.Callback()
-    @log
-    def _on_selection_changed(self, selection):
-        model, _iter = self._selection.get_selected()
-        self._select_button.props.sensitive = _iter is not None
+        for row in self._listbox:
+            row.props.selected = (row == selected_row)
 
     @Gtk.Template.Callback()
     @log
     def _on_editing_done(self, sender, data=None):
+        def select_and_close_dialog(playlist):
+            for row in self._listbox:
+                if row.props.playlist == playlist:
+                    self._listbox.select_row(row)
+                    break
+            self.response(Gtk.ResponseType.ACCEPT)
+
         text = self._add_playlist_entry.props.text
         if text:
-            self._playlist.create_playlist(text)
-
-    @log
-    def _on_playlist_created(self, playlists, item):
-        new_iter = self._add_item_to_model(item)
-        if new_iter and self._view.get_columns():
-            col0 = self._view.get_columns()[0]
-            path = self._model.get_path(new_iter)
-            self._view.set_cursor(path, col0, False)
-            self._view.row_activated(path, col0)
-            self.response(Gtk.ResponseType.ACCEPT)
+            self._coremodel.create_playlist(text, select_and_close_dialog)
 
     @Gtk.Template.Callback()
     @log
@@ -177,4 +144,4 @@ class PlaylistDialog(Gtk.Dialog):
     @Gtk.Template.Callback()
     @log
     def _on_add_playlist_entry_focused(self, editable, data=None):
-        self._selection.unselect_all()
+        self._listbox.unselect_all()
